@@ -78,7 +78,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Write systemd-aware daemons in Perl
-our $VERSION = '0.06_07'; # TRIAL VERSION
+our $VERSION = '0.06_08'; # TRIAL VERSION
 
 use parent 'Exporter::Tiny';
 
@@ -101,7 +101,9 @@ our @CARP_NOT = qw{ Try::Tiny };
 
 # --------------------------------------------------------------------------------------------------
 
-#pod =func notify( VAR => VALUE, … )
+#pod =func notify
+#pod
+#pod     $int = notify( VAR => VALUE, … );
 #pod
 #pod C<notify> is Perl wrapper for C functions C<sd_notify> and C<sd_pid_notify>, so read
 #pod L<sd_notify(3)|http://www.freedesktop.org/software/systemd/man/sd_notify.html> first.
@@ -125,10 +127,10 @@ our @CARP_NOT = qw{ Try::Tiny };
 #pod L<sd_notify(3)|http://www.freedesktop.org/software/systemd/man/sd_notify.html> describes some
 #pod "well-known" variable assignments, for example, C<RELOADING=1>. Systemd's reaction on assignment
 #pod C<RELOADING=2> is not defined. In my experiments with systemd v217 any value but C<1> does not have
-#pod any effect. To make C<notify> more Perlish, C<READY>, C<RELOADING>, C<STOPPING>, and C<WATCHDOG>
-#pod arguments are normalized: if its value is false (e. g. undef, zero or empty string), the respective
-#pod variable is not passed to underlying C function at all; if its value is true (not false), the
-#pod respective variable is set to C<1>.
+#pod any effect. To make C<notify> more Perlish, C<READY>, C<RELOADING>, C<STOPPING>, C<WATCHDOG>, and
+#pod C<FDSTORE> arguments are normalized: if its value is false (e. g. undef, zero or empty string), the
+#pod respective variable is not passed to underlying C function at all; if its value is true (not
+#pod false), the respective variable is set to C<1>.
 #pod
 #pod C<notify> returns result of underlying C<sd_notify> (or C<sd_pid_notify>). It should be negative
 #pod integer in case of error, zero if C<$ENV{ NOTIFY_SOCKET }> is not set (and so, C<systemd> cannot be
@@ -141,7 +143,7 @@ sub notify(@) {
     my ( %args ) = @_;
     my $pid   = delete( $args{ pid   } );
     my $unset = delete( $args{ unset } ) ? 1 : 0;
-    foreach my $k ( qw{ READY RELOADING STOPPING WATCHDOG } ) {
+    foreach my $k ( qw{ READY RELOADING STOPPING WATCHDOG FDSTORE } ) {
         delete( $args{ $k } ) and $args{ $k } = 1;
     }; # foreach
     my $state = join( '', map( { "$_=$args{ $_ }\n" } keys( %args ) ) );
@@ -206,8 +208,8 @@ sub _exporter_validate_opts {   ## no critic ( ProhibitUnusedPrivateSubroutines
 #pod
 #pod The module exports nothing by default. You have to specify symbols to import explicitly:
 #pod
-#pod     # Import function sd_listen_fds and constant SD_LISTEN_FDS_START:
-#pod     use Systemd::Daemon qw{ sd_listen_fds SD_LISTEN_FDS_START };
+#pod     # Import function sd_listen_fds and constant $SD_LISTEN_FDS_START:
+#pod     use Systemd::Daemon qw{ sd_listen_fds $SD_LISTEN_FDS_START };
 #pod
 #pod or use tags to import groups of related symbols:
 #pod
@@ -216,13 +218,13 @@ sub _exporter_validate_opts {   ## no critic ( ProhibitUnusedPrivateSubroutines
 #pod
 #pod Either colon (C<:>) or dash (C<->) can be used as tag prefix:
 #pod
-#pod     # The same as as above:
+#pod     # Ditto:
 #pod     use Systemd::Daemon qw{ -sd_listen };
 #pod
 #pod The module uses L<Exporter::Tiny> to export symbols, so all advanced import features like renaming
-#pod symbols, import to another package, import to a hash, importing by regexp, etc, can be used:
+#pod symbols, importing to another package, to a hash, by regexp, etc, can be used:
 #pod
-#pod     use Systemd::Daemon 'SD_ERR' => { -as => 'ERR' }, 'SD_DEBUG' => { -as => 'DBG' };
+#pod     use Systemd::Daemon '$SD_ERR' => { -as => 'ERR' }, '$SD_DEBUG' => { -as => 'DBG' };
 #pod     use Systemd::Daemon qw{ -all !notify };
 #pod
 #pod See L<Exporter::Tiny/"TIPS AND TRICKS IMPORTING FROM EXPORTER::TINY">.
@@ -237,9 +239,9 @@ sub _exporter_validate_opts {   ## no critic ( ProhibitUnusedPrivateSubroutines
 #pod = sd_is
 #pod sd_is_fifo, sd_is_mq, sd_is_socket, sd_is_socket_inet, sd_is_socket_unix, sd_is_special.
 #pod = sd_listen
-#pod SD_LISTEN_FDS_START, sd_listen_fds.
+#pod $SD_LISTEN_FDS_START, sd_listen_fds.
 #pod = sd_log
-#pod SD_ALERT, SD_CRIT, SD_DEBUG, SD_EMERG, SD_ERR, SD_INFO, SD_NOTICE, SD_WARNING.
+#pod $SD_ALERT, $SD_CRIT, $SD_DEBUG, $SD_EMERG, $SD_ERR, $SD_INFO, $SD_NOTICE, $SD_WARNING.
 #pod = sd_notify
 #pod sd_notify, sd_pid_notify.
 #pod = sd
@@ -252,12 +254,24 @@ our ( @EXPORT_OK, %EXPORT_TAGS );
 $EXPORT_TAGS{ all } = \@EXPORT_OK;
 $EXPORT_TAGS{ sd_booted } = [ qw{ sd_booted } ];
 $EXPORT_TAGS{ sd_is } = [ qw{ sd_is_fifo sd_is_mq sd_is_socket sd_is_socket_inet sd_is_socket_unix sd_is_special } ];
-$EXPORT_TAGS{ sd_listen } = [ qw{ SD_LISTEN_FDS_START sd_listen_fds } ];
-$EXPORT_TAGS{ sd_log } = [ qw{ SD_ALERT SD_CRIT SD_DEBUG SD_EMERG SD_ERR SD_INFO SD_NOTICE SD_WARNING } ];
+$EXPORT_TAGS{ sd_listen } = [ qw{ $SD_LISTEN_FDS_START sd_listen_fds } ];
+$EXPORT_TAGS{ sd_log } = [ qw{ $SD_ALERT $SD_CRIT $SD_DEBUG $SD_EMERG $SD_ERR $SD_INFO $SD_NOTICE $SD_WARNING } ];
 $EXPORT_TAGS{ sd_notify } = [ qw{ sd_notify sd_pid_notify } ];
 $EXPORT_TAGS{ sd_watchdog } = [ qw{  } ];
 @EXPORT_OK = map( { @{ $EXPORT_TAGS{ $_ } } } keys( %EXPORT_TAGS ) );
 $EXPORT_TAGS{ sd } = [ @{ $EXPORT_TAGS{ all } } ];
+## no critic ( ProhibitUnusedPrivateSubroutines )
+sub _exporter_expand_sub { ## no critic ( RequireArgUnpacking )
+    my $class = shift( @_ );
+    my ( $name, undef, undef, $permitted ) = @_;
+    if ( substr( $name, 0, 1 ) eq '$' and $name =~ $permitted ) {
+        $name = substr( $name, 1 );
+        no strict 'refs'; ## no critic( ProhibitNoStrict )
+        return $name => \${ $name };
+    } else {
+        return $class->SUPER::_exporter_expand_sub( @_ );
+    };
+};
 
 push( @EXPORT_OK, 'notify' );
 
@@ -299,7 +313,7 @@ Systemd::Daemon - Write systemd-aware daemons in Perl
 
 =head1 VERSION
 
-Version 0.06_07, released on 2015-11-09 21:29 UTC.
+Version 0.06_08, released on 2015-11-11 20:46 UTC.
 This is a B<trial release>.
 
 =head1 SYNOPSIS
@@ -353,8 +367,8 @@ Desired mode is specified as import pseudo-tag C<-hard> or C<-soft>:
 
 The module exports nothing by default. You have to specify symbols to import explicitly:
 
-    # Import function sd_listen_fds and constant SD_LISTEN_FDS_START:
-    use Systemd::Daemon qw{ sd_listen_fds SD_LISTEN_FDS_START };
+    # Import function sd_listen_fds and constant $SD_LISTEN_FDS_START:
+    use Systemd::Daemon qw{ sd_listen_fds $SD_LISTEN_FDS_START };
 
 or use tags to import groups of related symbols:
 
@@ -363,13 +377,13 @@ or use tags to import groups of related symbols:
 
 Either colon (C<:>) or dash (C<->) can be used as tag prefix:
 
-    # The same as as above:
+    # Ditto:
     use Systemd::Daemon qw{ -sd_listen };
 
 The module uses L<Exporter::Tiny> to export symbols, so all advanced import features like renaming
-symbols, import to another package, import to a hash, importing by regexp, etc, can be used:
+symbols, importing to another package, to a hash, by regexp, etc, can be used:
 
-    use Systemd::Daemon 'SD_ERR' => { -as => 'ERR' }, 'SD_DEBUG' => { -as => 'DBG' };
+    use Systemd::Daemon '$SD_ERR' => { -as => 'ERR' }, '$SD_DEBUG' => { -as => 'DBG' };
     use Systemd::Daemon qw{ -all !notify };
 
 See L<Exporter::Tiny/"TIPS AND TRICKS IMPORTING FROM EXPORTER::TINY">.
@@ -390,11 +404,11 @@ sd_is_fifo, sd_is_mq, sd_is_socket, sd_is_socket_inet, sd_is_socket_unix, sd_is_
 
 =item sd_listen
 
-SD_LISTEN_FDS_START, sd_listen_fds.
+$SD_LISTEN_FDS_START, sd_listen_fds.
 
 =item sd_log
 
-SD_ALERT, SD_CRIT, SD_DEBUG, SD_EMERG, SD_ERR, SD_INFO, SD_NOTICE, SD_WARNING.
+$SD_ALERT, $SD_CRIT, $SD_DEBUG, $SD_EMERG, $SD_ERR, $SD_INFO, $SD_NOTICE, $SD_WARNING.
 
 =item sd_notify
 
@@ -413,7 +427,9 @@ see L<Systemd::Daemon::XS/"FUNCTIONS">.
 
 Additionally, the module defines following functions:
 
-=head2 notify( VAR => VALUE, … )
+=head2 notify
+
+    $int = notify( VAR => VALUE, … );
 
 C<notify> is Perl wrapper for C functions C<sd_notify> and C<sd_pid_notify>, so read
 L<sd_notify(3)|http://www.freedesktop.org/software/systemd/man/sd_notify.html> first.
@@ -437,10 +453,10 @@ C<unset> is defaulted to zero.
 L<sd_notify(3)|http://www.freedesktop.org/software/systemd/man/sd_notify.html> describes some
 "well-known" variable assignments, for example, C<RELOADING=1>. Systemd's reaction on assignment
 C<RELOADING=2> is not defined. In my experiments with systemd v217 any value but C<1> does not have
-any effect. To make C<notify> more Perlish, C<READY>, C<RELOADING>, C<STOPPING>, and C<WATCHDOG>
-arguments are normalized: if its value is false (e. g. undef, zero or empty string), the respective
-variable is not passed to underlying C function at all; if its value is true (not false), the
-respective variable is set to C<1>.
+any effect. To make C<notify> more Perlish, C<READY>, C<RELOADING>, C<STOPPING>, C<WATCHDOG>, and
+C<FDSTORE> arguments are normalized: if its value is false (e. g. undef, zero or empty string), the
+respective variable is not passed to underlying C function at all; if its value is true (not
+false), the respective variable is set to C<1>.
 
 C<notify> returns result of underlying C<sd_notify> (or C<sd_pid_notify>). It should be negative
 integer in case of error, zero if C<$ENV{ NOTIFY_SOCKET }> is not set (and so, C<systemd> cannot be
