@@ -46,7 +46,7 @@ use warnings;
 use parent 'Exporter::Tiny';
 
 # ABSTRACT: Perl bindings to libsystemd.
-our $VERSION = '0.06_07'; # TRIAL VERSION
+our $VERSION = '0.06_08'; # TRIAL VERSION
 
 ## no critic ( ProhibitImplicitNewlines )
 use Systemd::Daemon::XS::Inline
@@ -78,20 +78,28 @@ use Systemd::Daemon::XS::Inline
 
 #pod =pod
 #pod
-#pod =func int sd_listen_fds( int unset_environment );
+#pod =func sd_listen_fds
+#pod
+#pod     int sd_listen_fds( int unset_environment );
 #pod
 #pod
 #pod See L<sd_listen_fds(3)|http://www.freedesktop.org/software/systemd/man/sd_listen_fds.html>.
 #pod
-#pod =func int sd_notify( int unset_environment, const char * state );
+#pod =func sd_notify
 #pod
-#pod =func // int sd_notifyf( int unset_environment, const char * format, ... );
+#pod =func sd_notifyf
 #pod
-#pod =func int sd_pid_notify( pid_t pid, int unset_environment, const char * state );
+#pod =func sd_pid_notify
 #pod
-#pod =func // int sd_pid_notify_with_fds( pid_t pid, int unset_environment, const char * state, const int * fds, unsigned n_fds );
+#pod =func sd_pid_notify_with_fds
 #pod
-#pod =func // int sd_pid_notifyf( int pid, int unset_environment, const char * format, ... );
+#pod =func sd_pid_notifyf
+#pod
+#pod     int sd_notify( int unset_environment, const char * state );
+#pod     // int sd_notifyf( int unset_environment, const char * format, ... );
+#pod     int sd_pid_notify( pid_t pid, int unset_environment, const char * state );
+#pod     // int sd_pid_notify_with_fds( pid_t pid, int unset_environment, const char * state, const int * fds, unsigned n_fds );
+#pod     // int sd_pid_notifyf( int pid, int unset_environment, const char * format, ... );
 #pod
 #pod
 #pod See L<sd_notify(3)|http://www.freedesktop.org/software/systemd/man/sd_notify.html> for details.
@@ -115,27 +123,38 @@ use Systemd::Daemon::XS::Inline
 #pod Such implementation is not included into C<Systemd::Daemon::XS> because it is not a binding to
 #pod C<libsystemd>.
 #pod
-#pod =func int sd_booted();
+#pod =func sd_booted
+#pod
+#pod     int sd_booted();
 #pod
 #pod
 #pod See L<sd_booted(3)|http://www.freedesktop.org/software/systemd/man/sd_booted.html>.
 #pod
-#pod =func int sd_is_fifo( int fd, const char * path );
+#pod =func sd_is_fifo
 #pod
-#pod =func int sd_is_mq( int fd, const char * path );
+#pod =func sd_is_mq
 #pod
-#pod =func int sd_is_socket( int fd, int family, int type, int listening );
+#pod =func sd_is_socket
 #pod
-#pod =func int sd_is_socket_inet( int fd, int family, int type, int listening, uint16_t port );
+#pod =func sd_is_socket_inet
 #pod
-#pod =func int sd_is_socket_unix( int fd, int family, int type, int listening, const char * path, size_t length );
+#pod =func sd_is_socket_unix
 #pod
-#pod =func int sd_is_special( int fd, const char * path );
+#pod =func sd_is_special
+#pod
+#pod     int sd_is_fifo( int fd, const char * path );
+#pod     int sd_is_mq( int fd, const char * path );
+#pod     int sd_is_socket( int fd, int family, int type, int listening );
+#pod     int sd_is_socket_inet( int fd, int family, int type, int listening, uint16_t port );
+#pod     int sd_is_socket_unix( int fd, int family, int type, int listening, const char * path, size_t length );
+#pod     int sd_is_special( int fd, const char * path );
 #pod
 #pod
 #pod See L<sd_is_fifo(3)|http://www.freedesktop.org/software/systemd/man/sd_is_fifo.html>.
 #pod
-#pod =func // int sd_watchdog_enabled( int unset_environment, uint64_t * usec );
+#pod =func sd_watchdog_enabled
+#pod
+#pod     // int sd_watchdog_enabled( int unset_environment, uint64_t * usec );
 #pod
 #pod
 #pod See L<sd_watchdog_enabled(3)|http://www.freedesktop.org/software/systemd/man/sd_watchdog_enabled.html>.
@@ -144,53 +163,56 @@ use Systemd::Daemon::XS::Inline
 #pod
 #pod =cut
 
-#pod =pod
+#pod =head1 CONSTANTS
 #pod
-#pod =const SD_ALERT
+#pod Constants described below are not traditional 0-ary functions created by C<constant> pragma, but
+#pod immutable variables created by C<Readonly> module, so you have to use sigils but can interpolate
+#pod constants to strings.
 #pod
-#pod =const SD_CRIT
+#pod =const $SD_ALERT
 #pod
-#pod =const SD_DEBUG
+#pod =const $SD_CRIT
 #pod
-#pod =const SD_EMERG
+#pod =const $SD_DEBUG
 #pod
-#pod =const SD_ERR
+#pod =const $SD_EMERG
 #pod
-#pod =const SD_INFO
+#pod =const $SD_ERR
 #pod
-#pod =const SD_NOTICE
+#pod =const $SD_INFO
 #pod
-#pod =const SD_WARNING
+#pod =const $SD_NOTICE
+#pod
+#pod =const $SD_WARNING
 #pod
 #pod
 #pod See L<sd-daemon(3)|http://www.freedesktop.org/software/systemd/man/sd-daemon.html>.
 #pod
-#pod =const SD_LISTEN_FDS_START
+#pod =const $SD_LISTEN_FDS_START
 #pod
 #pod
 #pod See L<sd_listen_fds(3)|http://www.freedesktop.org/software/systemd/man/sd_listen_fds.html>.
 #pod
 #pod =cut
 
-use constant {
-    SD_LISTEN_FDS_START => '3',
-    SD_ALERT => '<1>',
-    SD_CRIT => '<2>',
-    SD_DEBUG => '<7>',
-    SD_EMERG => '<0>',
-    SD_ERR => '<3>',
-    SD_INFO => '<6>',
-    SD_NOTICE => '<5>',
-    SD_WARNING => '<4>',
-};
+use Readonly;
+our $SD_LISTEN_FDS_START; Readonly $SD_LISTEN_FDS_START => 3;
+our $SD_ALERT; Readonly $SD_ALERT => '<1>';
+our $SD_CRIT; Readonly $SD_CRIT => '<2>';
+our $SD_DEBUG; Readonly $SD_DEBUG => '<7>';
+our $SD_EMERG; Readonly $SD_EMERG => '<0>';
+our $SD_ERR; Readonly $SD_ERR => '<3>';
+our $SD_INFO; Readonly $SD_INFO => '<6>';
+our $SD_NOTICE; Readonly $SD_NOTICE => '<5>';
+our $SD_WARNING; Readonly $SD_WARNING => '<4>';
 
 
 #pod =head1 EXPORT
 #pod
 #pod The module exports nothing by default. You have to specify symbols to import explicitly:
 #pod
-#pod     # Import function sd_listen_fds and constant SD_LISTEN_FDS_START:
-#pod     use Systemd::Daemon::XS qw{ sd_listen_fds SD_LISTEN_FDS_START };
+#pod     # Import function sd_listen_fds and constant $SD_LISTEN_FDS_START:
+#pod     use Systemd::Daemon::XS qw{ sd_listen_fds $SD_LISTEN_FDS_START };
 #pod
 #pod or use tags to import groups of related symbols:
 #pod
@@ -199,13 +221,13 @@ use constant {
 #pod
 #pod Either colon (C<:>) or dash (C<->) can be used as tag prefix:
 #pod
-#pod     # The same as as above:
+#pod     # Ditto:
 #pod     use Systemd::Daemon::XS qw{ -sd_listen };
 #pod
 #pod The module uses L<Exporter::Tiny> to export symbols, so all advanced import features like renaming
-#pod symbols, import to another package, import to a hash, importing by regexp, etc, can be used:
+#pod symbols, importing to another package, to a hash, by regexp, etc, can be used:
 #pod
-#pod     use Systemd::Daemon::XS 'SD_ERR' => { -as => 'ERR' }, 'SD_DEBUG' => { -as => 'DBG' };
+#pod     use Systemd::Daemon::XS '$SD_ERR' => { -as => 'ERR' }, '$SD_DEBUG' => { -as => 'DBG' };
 #pod     use Systemd::Daemon::XS qw{ -all !sd_notify };
 #pod
 #pod See L<tips and tricks|Exporter::Tiny/"TIPS AND TRICKS IMPORTING FROM EXPORTER::TINY">.
@@ -220,9 +242,9 @@ use constant {
 #pod = sd_is
 #pod sd_is_fifo, sd_is_mq, sd_is_socket, sd_is_socket_inet, sd_is_socket_unix, sd_is_special.
 #pod = sd_listen
-#pod SD_LISTEN_FDS_START, sd_listen_fds.
+#pod $SD_LISTEN_FDS_START, sd_listen_fds.
 #pod = sd_log
-#pod SD_ALERT, SD_CRIT, SD_DEBUG, SD_EMERG, SD_ERR, SD_INFO, SD_NOTICE, SD_WARNING.
+#pod $SD_ALERT, $SD_CRIT, $SD_DEBUG, $SD_EMERG, $SD_ERR, $SD_INFO, $SD_NOTICE, $SD_WARNING.
 #pod = sd_notify
 #pod sd_notify, sd_pid_notify.
 #pod = sd
@@ -235,11 +257,23 @@ our ( @EXPORT_OK, %EXPORT_TAGS );
 $EXPORT_TAGS{ all } = \@EXPORT_OK;
 $EXPORT_TAGS{ sd_booted } = [ qw{ sd_booted } ];
 $EXPORT_TAGS{ sd_is } = [ qw{ sd_is_fifo sd_is_mq sd_is_socket sd_is_socket_inet sd_is_socket_unix sd_is_special } ];
-$EXPORT_TAGS{ sd_listen } = [ qw{ SD_LISTEN_FDS_START sd_listen_fds } ];
-$EXPORT_TAGS{ sd_log } = [ qw{ SD_ALERT SD_CRIT SD_DEBUG SD_EMERG SD_ERR SD_INFO SD_NOTICE SD_WARNING } ];
+$EXPORT_TAGS{ sd_listen } = [ qw{ $SD_LISTEN_FDS_START sd_listen_fds } ];
+$EXPORT_TAGS{ sd_log } = [ qw{ $SD_ALERT $SD_CRIT $SD_DEBUG $SD_EMERG $SD_ERR $SD_INFO $SD_NOTICE $SD_WARNING } ];
 $EXPORT_TAGS{ sd_notify } = [ qw{ sd_notify sd_pid_notify } ];
 $EXPORT_TAGS{ sd_watchdog } = [ qw{  } ];
 @EXPORT_OK = map( { @{ $EXPORT_TAGS{ $_ } } } keys( %EXPORT_TAGS ) );
+## no critic ( ProhibitUnusedPrivateSubroutines )
+sub _exporter_expand_sub { ## no critic ( RequireArgUnpacking )
+    my $class = shift( @_ );
+    my ( $name, undef, undef, $permitted ) = @_;
+    if ( substr( $name, 0, 1 ) eq '$' and $name =~ $permitted ) {
+        $name = substr( $name, 1 );
+        no strict 'refs'; ## no critic( ProhibitNoStrict )
+        return $name => \${ $name };
+    } else {
+        return $class->SUPER::_exporter_expand_sub( @_ );
+    };
+};
 
 
 #pod =head1 SEE ALSO
@@ -251,6 +285,7 @@ $EXPORT_TAGS{ sd_watchdog } = [ qw{  } ];
 #pod *   L<sd_is_fifo(3)|http://www.freedesktop.org/software/systemd/man/sd_is_fifo.html>
 #pod *   L<sd_watchdog_enabled(3)|http://www.freedesktop.org/software/systemd/man/sd_watchdog_enabled.html>
 #pod *   L<Exporter::Tiny>
+#pod *   L<Readonly>
 #pod
 #pod =head1 COPYRIGHT AND LICENSE
 #pod
@@ -281,7 +316,7 @@ Systemd::Daemon::XS - Perl bindings to libsystemd.
 
 =head1 VERSION
 
-Version 0.06_07, released on 2015-11-09 21:29 UTC.
+Version 0.06_08, released on 2015-11-11 20:46 UTC.
 This is a B<trial release>.
 
 =head1 SYNOPSIS
@@ -304,8 +339,8 @@ This module provides Perl bindings to the part of F<libsystemd> shared library d
 
 The module exports nothing by default. You have to specify symbols to import explicitly:
 
-    # Import function sd_listen_fds and constant SD_LISTEN_FDS_START:
-    use Systemd::Daemon::XS qw{ sd_listen_fds SD_LISTEN_FDS_START };
+    # Import function sd_listen_fds and constant $SD_LISTEN_FDS_START:
+    use Systemd::Daemon::XS qw{ sd_listen_fds $SD_LISTEN_FDS_START };
 
 or use tags to import groups of related symbols:
 
@@ -314,13 +349,13 @@ or use tags to import groups of related symbols:
 
 Either colon (C<:>) or dash (C<->) can be used as tag prefix:
 
-    # The same as as above:
+    # Ditto:
     use Systemd::Daemon::XS qw{ -sd_listen };
 
 The module uses L<Exporter::Tiny> to export symbols, so all advanced import features like renaming
-symbols, import to another package, import to a hash, importing by regexp, etc, can be used:
+symbols, importing to another package, to a hash, by regexp, etc, can be used:
 
-    use Systemd::Daemon::XS 'SD_ERR' => { -as => 'ERR' }, 'SD_DEBUG' => { -as => 'DBG' };
+    use Systemd::Daemon::XS '$SD_ERR' => { -as => 'ERR' }, '$SD_DEBUG' => { -as => 'DBG' };
     use Systemd::Daemon::XS qw{ -all !sd_notify };
 
 See L<tips and tricks|Exporter::Tiny/"TIPS AND TRICKS IMPORTING FROM EXPORTER::TINY">.
@@ -341,11 +376,11 @@ sd_is_fifo, sd_is_mq, sd_is_socket, sd_is_socket_inet, sd_is_socket_unix, sd_is_
 
 =item sd_listen
 
-SD_LISTEN_FDS_START, sd_listen_fds.
+$SD_LISTEN_FDS_START, sd_listen_fds.
 
 =item sd_log
 
-SD_ALERT, SD_CRIT, SD_DEBUG, SD_EMERG, SD_ERR, SD_INFO, SD_NOTICE, SD_WARNING.
+$SD_ALERT, $SD_CRIT, $SD_DEBUG, $SD_EMERG, $SD_ERR, $SD_INFO, $SD_NOTICE, $SD_WARNING.
 
 =item sd_notify
 
@@ -359,43 +394,55 @@ All above.
 
 =head1 CONSTANTS
 
-=head2 SD_ALERT
+Constants described below are not traditional 0-ary functions created by C<constant> pragma, but
+immutable variables created by C<Readonly> module, so you have to use sigils but can interpolate
+constants to strings.
 
-=head2 SD_CRIT
+=head2 $SD_ALERT
 
-=head2 SD_DEBUG
+=head2 $SD_CRIT
 
-=head2 SD_EMERG
+=head2 $SD_DEBUG
 
-=head2 SD_ERR
+=head2 $SD_EMERG
 
-=head2 SD_INFO
+=head2 $SD_ERR
 
-=head2 SD_NOTICE
+=head2 $SD_INFO
 
-=head2 SD_WARNING
+=head2 $SD_NOTICE
+
+=head2 $SD_WARNING
 
 See L<sd-daemon(3)|http://www.freedesktop.org/software/systemd/man/sd-daemon.html>.
 
-=head2 SD_LISTEN_FDS_START
+=head2 $SD_LISTEN_FDS_START
 
 See L<sd_listen_fds(3)|http://www.freedesktop.org/software/systemd/man/sd_listen_fds.html>.
 
 =head1 FUNCTIONS
 
-=head2 int sd_listen_fds( int unset_environment );
+=head2 sd_listen_fds
+
+    int sd_listen_fds( int unset_environment );
 
 See L<sd_listen_fds(3)|http://www.freedesktop.org/software/systemd/man/sd_listen_fds.html>.
 
-=head2 int sd_notify( int unset_environment, const char * state );
+=head2 sd_notify
 
-=head2 // int sd_notifyf( int unset_environment, const char * format, ... );
+=head2 sd_notifyf
 
-=head2 int sd_pid_notify( pid_t pid, int unset_environment, const char * state );
+=head2 sd_pid_notify
 
-=head2 // int sd_pid_notify_with_fds( pid_t pid, int unset_environment, const char * state, const int * fds, unsigned n_fds );
+=head2 sd_pid_notify_with_fds
 
-=head2 // int sd_pid_notifyf( int pid, int unset_environment, const char * format, ... );
+=head2 sd_pid_notifyf
+
+    int sd_notify( int unset_environment, const char * state );
+    // int sd_notifyf( int unset_environment, const char * format, ... );
+    int sd_pid_notify( pid_t pid, int unset_environment, const char * state );
+    // int sd_pid_notify_with_fds( pid_t pid, int unset_environment, const char * state, const int * fds, unsigned n_fds );
+    // int sd_pid_notifyf( int pid, int unset_environment, const char * format, ... );
 
 See L<sd_notify(3)|http://www.freedesktop.org/software/systemd/man/sd_notify.html> for details.
 
@@ -418,25 +465,36 @@ Also, it can be reimplemented in Perl:
 Such implementation is not included into C<Systemd::Daemon::XS> because it is not a binding to
 C<libsystemd>.
 
-=head2 int sd_booted();
+=head2 sd_booted
+
+    int sd_booted();
 
 See L<sd_booted(3)|http://www.freedesktop.org/software/systemd/man/sd_booted.html>.
 
-=head2 int sd_is_fifo( int fd, const char * path );
+=head2 sd_is_fifo
 
-=head2 int sd_is_mq( int fd, const char * path );
+=head2 sd_is_mq
 
-=head2 int sd_is_socket( int fd, int family, int type, int listening );
+=head2 sd_is_socket
 
-=head2 int sd_is_socket_inet( int fd, int family, int type, int listening, uint16_t port );
+=head2 sd_is_socket_inet
 
-=head2 int sd_is_socket_unix( int fd, int family, int type, int listening, const char * path, size_t length );
+=head2 sd_is_socket_unix
 
-=head2 int sd_is_special( int fd, const char * path );
+=head2 sd_is_special
+
+    int sd_is_fifo( int fd, const char * path );
+    int sd_is_mq( int fd, const char * path );
+    int sd_is_socket( int fd, int family, int type, int listening );
+    int sd_is_socket_inet( int fd, int family, int type, int listening, uint16_t port );
+    int sd_is_socket_unix( int fd, int family, int type, int listening, const char * path, size_t length );
+    int sd_is_special( int fd, const char * path );
 
 See L<sd_is_fifo(3)|http://www.freedesktop.org/software/systemd/man/sd_is_fifo.html>.
 
-=head2 // int sd_watchdog_enabled( int unset_environment, uint64_t * usec );
+=head2 sd_watchdog_enabled
+
+    // int sd_watchdog_enabled( int unset_environment, uint64_t * usec );
 
 See L<sd_watchdog_enabled(3)|http://www.freedesktop.org/software/systemd/man/sd_watchdog_enabled.html>.
 
@@ -472,6 +530,10 @@ L<sd_watchdog_enabled(3)|http://www.freedesktop.org/software/systemd/man/sd_watc
 
 L<Exporter::Tiny>
 
+=item *
+
+L<Readonly>
+
 =back
 
 =head1 AUTHOR
